from ccai.client import Client

def test_create_smart_order():
  # create smart order that will
  # entry with market order
  # set take-profit targets at 8% profit with 40% of amount and 15% with 60% of amount
  # set stop-loss at 10%

  client = Client('SECRET',
                  'KEYID')
  smart_order = {
    "marketType": 1,  # 0 - spot, 1 - futures
    "pair": "BTC_USDT",
    "stopLoss": 10.0,  # 10% loss
    "stopLossType": "limit",  # will place stop-limit or stop-market for stop-loss
    "leverage": 125,  # leverage
    "entryOrder": {
      "side": "buy",
      "orderType": "market",
      "type": 0,  # not using yet, just place 0
      "amount": 0.01  # btc amount (after leverage)
    },
    "exitLevels": [
      {
        "price": 8, # 8% profit
        "amount": 40, # 40% from entry
        "type": 1, # 1 - means amount and price is in percentage
        "orderType": "limit"
      },
      {
        "price": 15, # 15% profit
        "amount": 60, # 60% from entry
        "type": 1, # 1 - means amount and price is in percentage
        "orderType": "limit"
      }
    ]
  }
  response = client.create_order(params=smart_order)
  print(response)

def test_get_balances():
  client = Client('apisecret', 'keyid')
  response = client.get_balances()
  print(response)

#test_create_smart_order()
#test_get_balances()
test_create_smart_order()




from ccai.client import Client

def test_create_smart_order():
  # create SM that will go into entry
  # and place 3 targets
  # stop-loss at 7% loss from entry price

  client = Client('SECRET',
                  'KEYID')
  smart_order = {
    "marketType": 1,  # 0 - spot, 1 - futures
    "pair": "BTC_USDT",
    "stopLoss": 7.0,  # 7% loss
    "stopLossType": "limit",  # will place stop-limit or stop-market
    "leverage": 125,  # leverage
    "entryOrder": {
      "side": "buy",
      "orderType": "market",
      "type": 0,  # not using yet, just place 0
      "activatePrice": 9120,  # start into trailing once price crosses 9120
      "entryDeviation": 5,  # buy on 5% rebounce
      "amount": 0.01  # btc amount
    },
    "exitLevels": [
      {
        "price": 15,  # 15% profit
        "amount": 30,  # 70% from entry
        "type": 1,  # 1 - means amount and price is in percentage
        "orderType": "limit"
      },
      {
        "price": 25,  # 15% profit
        "amount": 30,  # 30% from entry
        "type": 1,  # 1 - means amount and price is in percentage
        "orderType": "limit"
      },
      {
        "price": 30,  # 30% profit
        "amount": 40,  # 30% from entry
        "type": 1,  # 1 - means amount and price is in percentage
        "orderType": "market"
      }
    ]
  }
  response = client.create_order(params=smart_order)
  print(response)

def test_get_balances():
  client = Client('apisecret', 'keyid')
  response = client.get_balances()
  print(response)

test_create_smart_order()




from six.moves import urllib
import json

class Client(object):
  API_URL = 'https://develop.api.cryptocurrencies.ai/graphql'

  def __init__(self, api_key=None, key_id = ""):
    """CCAI API Client constructor
    :param api_key: Api Key you generated
    """

    self.API_KEY = api_key
    self.keyId = key_id
    self.response = None

  # returns string, for example "Waiting"
  def get_order_status(self, **params):
    query = "query getStrategyStatus($input: getStrategyStatusInput!){\n  getStrategyStatus(input: $input)\n}"
    params["params"]["accountId"] = self.keyId
    mutation_params = {}
    mutation_params["keyId"] = self.keyId
    mutation_params["strategyId"] = params["params"]["strategyId"]
    params = {
      "input": mutation_params
    }

    try:
      response = self._send(query, variables=params)
      return json.loads(response)["data"]["getStrategyStatus"]
    except:
      print('Exception occurred')

  # returns state of order
  def cancel_order(self, **params):
    query = "mutation disableStrategy($input: disableStrategyInput!) {\n    disableStrategy(input: $input) {\n      state {\n        state\n      }\n    }\n}"
    params["params"]["accountId"] = self.keyId
    mutation_params = {}
    mutation_params["keyId"] = self.keyId
    mutation_params["strategyId"] = params["params"]["strategyId"]
    params = {
      "input": mutation_params
    }
    try:
      response = self._send(query, variables=params)
      return json.loads(response)["data"]["disableStrategy"]["state"]
    except:
      print('Exception occurred')

  # returns new order id as string, for example "5e2b08dd1a1f278b0c2084e9"
  def create_order(self, **params):
    query = "mutation createOrder($keyId: String!, $keyParams: createOrderParams!) {\n  createOrder(keyId: $keyId, keyParams: $keyParams) {\n    status\n    orderId\n }\n}\n"
    params["params"]["accountId"] = self.keyId
    mutation_params = {}
    mutation_params["keyId"] = self.keyId
    mutation_params["keyParams"] = {
      "type": "smart",
      "params": {"smartOrder": params["params"]},
      "symbol": "0", # остальные поля не нужны но обязательны (поправлю в апи потом)
      "amount": 0,
      "side": "0",
    }
    response = self._send(query, variables=mutation_params)
    decoded = json.loads(response)
    if decoded["data"]["createOrder"]["status"] == "OK":
      return decoded["data"]["createOrder"]["orderId"]
    else:
      return "ERR"

  '''
    returns array of balances for all key assets. For example:
    [
     {'assetType': 0, 'locked': 0, 'free': 31.86915117, 'asset': {'symbol': 'USDT', 'priceUSD': 1}},
     {'assetType': 1, 'locked': 4.4637389899999995, 'free': 3.12550607, 'asset': {'symbol': 'USDT', 'priceUSD': 1}},
     {'assetType': 0, 'locked': 0, 'free': 3.1e-07, 'asset': {'symbol': 'BTC', 'priceUSD': 8471.26}}, 
     {'assetType': 1, 'locked': 0, 'free': 0, 'asset': {'symbol': 'BNB', 'priceUSD': 17.3495}},
     {'assetType': 0, 'locked': 0, 'free': 0, 'asset': {'symbol': 'BCH', 'priceUSD': 0}}, 
     {'assetType': 0, 'locked': 0, 'free': 0, 'asset': {'symbol': 'ETH', 'priceUSD': 161.62}}
    ]
  '''
  def get_balances(self):
    query = "query getFunds($fundsInput: fundsInput!) {\n getFunds(fundsInput: $fundsInput) {\n assetType\n locked \n free \n asset { \n symbol \n priceUSD\n }\n }\n}\n"
    query_params = {}
    query_params["fundsInput"] = {
      "activeExchangeKey": self.keyId
    }

    try:
      response = self._send(query, variables=query_params)
      return json.loads(response)["data"]["getFunds"]
    except:
      print('Exception occurred')

  def _send(self, query, variables):
    data = {'query': query,
            'variables': variables}
    print(json.dumps(data).encode('utf-8'))
    headers = {'Accept': 'application/json',
               'Content-Type': 'application/json'}
    headers['apikey'] = '{}'.format(self.API_KEY)

    req = urllib.request.Request(self.API_URL, json.dumps(data).encode('utf-8'), headers)
    try:
      response = urllib.request.urlopen(req)
      return response.read().decode('utf-8')
    except urllib.error.HTTPError as e:
      print((e.read()))
      print('')
      raise e


import sys
sys.path.append('../../ccai')

from ccai.client import Client

def test_create_smart_order():
  #  create smart order that will
  #  entry with market order
  #  set take-profit targets at 8% profit with 40% of amount and 15% with 60% of amount
  #  set stop-loss at 10%

  client = Client('a1cb94dab42cd389ce7327a147a5acb4bc92fc66207b09a105ade2e186025239a51572cab8bcb0f5103cbe2115e462846ad721ae5ebf947d2ddfde4172352775ac8ca97ec6994b3abc1aee1169327bf97feca9abe7ceee84a7f8f2b7057b21432362e403ab59874615ee7be01ae4ea93a3fd977095bb3bad97dcc0ec1e9a7633c4b2e7e6839b6712f73666f46e5c4041a633ceab2702ca235fa5f588eac059608cb3b8546a248a7ff3ec6521d3d89f8246baa3ba87d3a8641c99d29b3f37ab0d70550b97b6ca079b54f52fff14900e78a7e932fe22d2bfa2778a956477aab88adfa883c09b2cf291f7c7630bbbc6c60ba9c40edd700796668ed916455b46699c',
                  '5ded5307240b81f3012372de')
  smart_order = {
    "marketType": 1,  # 0 - spot, 1 - futures
    "pair": "BTC_USDT",
    "stopLoss": 10.0,  # 10% loss
    "stopLossType": "limit",  # will place stop-limit or stop-market for stop-loss
    "leverage": 125,  # leverage
    "waitingEntryTimeout": 100,   # if didnt get in entry for 100 seconds - cancel SM
    "activationMoveStep": 1,      # move activatePrice 1% closed
    "activationMoveTimeout": 5,   # waiting 5 seconds before moving activatePrice
    "entryOrder": {
      "side": "buy",
      "orderType": "market",
      "activatePrice": 9950,
      "entryDeviation": 15,
      "type": 0,  # not using yet, just place 0
      "amount": 0.001  # btc amount (after leverage)
    },
    "exitLevels": [
      {
        "price": 8, # 8% profit
        "amount": 40, # 40% from entry
        "type": 1, # 1 - means amount and price is in percentage
        "orderType": "limit"
      }
    ]
  }
  response = client.create_order(params=smart_order)
  print(response)

test_create_smart_order()




from ccai.client import Client

def test_create_smart_order():
  # trailing entry -> trailing take profit

  client = Client('SECRET',
                  'KEYID')
  smart_order = {
    "marketType": 1, # 0 - spot, 1 - futures
    "pair": "BTC_USDT",
    "stopLoss": 10.0, # 7% loss
    "stopLossType": "limit", # will place stop-limit or stop-market
    "leverage": 30, # leverage
    "entryOrder": {
      "side": "buy",
      "orderType": "limit",
      "type": 0, # not using yet, just place 0
      "amount": 0.01, # btc amount
    },
    "exitLevels": [
      {
        "amount": 100, # 70% from entry
        "activatePrice": 10,  # will start trailing and follow the trend after 10% profit
        "entryDeviation": 5,  # exit on 5% rebounce
        "type": 1, # 1 - means amount and price is in percentage
        "orderType": "market"
      },
    ]
  }
  response = client.create_order(params=smart_order)
  print(response)

def test_get_balances():
  client = Client('apikey', 'keyid')
  response = client.get_balances()
  print(response)

#test_create_smart_order()
#test_get_balances()
test_create_smart_order()

